# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.wrapped_response_team_member_access_response import WrappedResponseTeamMemberAccessResponse  # noqa: E501

class TestWrappedResponseTeamMemberAccessResponse(unittest.TestCase):
    """WrappedResponseTeamMemberAccessResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseTeamMemberAccessResponse:
        """Test WrappedResponseTeamMemberAccessResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseTeamMemberAccessResponse`
        """
        model = WrappedResponseTeamMemberAccessResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseTeamMemberAccessResponse(
                done = true,
                result = team_member_server_sdk.models.team_member_access_response.TeamMemberAccessResponse(
                    portal_member_id = 56, 
                    team_member_role = team_member_server_sdk.models.team_member_role_schema.TeamMemberRoleSchema(
                        id = 56, 
                        title = '', 
                        enabled_at = 56, 
                        action_codes = [
                            ''
                            ], 
                        scopes = team_member_server_sdk.models.scope_schema.ScopeSchema(
                            course_ids = [
                                56
                                ], 
                            community_ids = [
                                56
                                ], ), ), )
            )
        else:
            return WrappedResponseTeamMemberAccessResponse(
                result = team_member_server_sdk.models.team_member_access_response.TeamMemberAccessResponse(
                    portal_member_id = 56, 
                    team_member_role = team_member_server_sdk.models.team_member_role_schema.TeamMemberRoleSchema(
                        id = 56, 
                        title = '', 
                        enabled_at = 56, 
                        action_codes = [
                            ''
                            ], 
                        scopes = team_member_server_sdk.models.scope_schema.ScopeSchema(
                            course_ids = [
                                56
                                ], 
                            community_ids = [
                                56
                                ], ), ), ),
        )
        """

    def testWrappedResponseTeamMemberAccessResponse(self):
        """Test WrappedResponseTeamMemberAccessResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
