# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ActionOperation(str, Enum):
    """
    ActionOperation
    """

    """
    allowed enum values
    """
    ADD = 'add'
    REMOVE = 'remove'

    @classmethod
    def from_json(cls, json_str: str) -> ActionOperation:
        """Create an instance of ActionOperation from a JSON string"""
        return ActionOperation(json.loads(json_str))


